@@ -14,5 +14,15 @@ if (!strpos($REFERER_AND_QUERY, "from_menu=yes")) {
 		$REFERER_AND_QUERY = $REFERER_AND_QUERY . "&from_menu=yes";
 	}
 }
+if ($frames) { ?>
+<script language="JavaScript">
+<!--
+parent.categories.location.reload('<?=$CFG->wwwroot?>/shopping/navigation.php?p=0');
+parent.main.location.href="<?=$REFERER_AND_QUERY?>";
+// -->
+</script>
+<?
+} else {
 header("Location: $REFERER_AND_QUERY");
+}
 ?>
