@@ -107,13 +107,36 @@ function build_category_navigator(&$output, $parent=1, $indent="..") {
         $numr = db_num_rows($qid);
         for ($i=0;$i<$numr;$i++) {
                 $cat =  db_fetch_object($qid, $i);
-		$output .= $indent . "<div class=normal>" . stripslashes($cat->name) . "</div>" . "^" . $CFG->wwwroot . "/shopping/?" . getenv("QUERY_STRING") . "&id=" . $cat->id . "^main" . "\n";
+		$output .= $indent . $cat->name . "^" . $CFG->wwwroot . "/shopping/?" . getenv("QUERY_STRING") . "&id=" . $cat->id . "^main" . "\n";
                 if ($cat->id != $parent) {
                         build_category_navigator($output, $cat->id, $indent.".");
                 }
         }
 }
 
+function build_category_navigator_js(&$output, $parent=1, $indent="..") {
+/* recursively go through the category tree, starting at a parent, and
+ * drill down, printing options for a selection list box.
+ * this is not an efficient algorithm because it has to issue
+ * one query per category!!  it's only used because it is easy to understand.
+ */
+	global $CFG;
+
+        $qid = db_query("SELECT id, name FROM categories WHERE parent_id = '$parent' AND id <> 1 ORDER BY on_special, name");
+
+        $numr = db_num_rows($qid);
+        for ($i=0;$i<$numr;$i++) {
+                $cat =  db_fetch_object($qid, $i);
+//		if (getenv("QUERY_STRING") == "")
+			$output .= $indent . $cat->name . "^" . $CFG->wwwroot . "/shopping/?id=" . $cat->id . "\n";
+//		else
+//			$output .= $indent . $cat->name . "^" . $CFG->wwwroot . "/shopping/?" . getenv("QUERY_STRING") . "&id=" . $cat->id . "\n";
+                if ($cat->id != $parent) {
+                        build_category_navigator_js($output, $cat->id, $indent.".");
+                }
+        }
+}
+
 function generate_password($maxlen=10) {
 /* returns a randomly generated password of length $maxlen.  inspired by
  * http://www.phpbuilder.com/columns/jesus19990502.php3 */
@@ -171,7 +194,7 @@ function reset_user_password($username) {
 	/* load up the user record */
 	$qid = db_query("SELECT username, priv, firstname, lastname, email FROM users WHERE username = '$username'");
 	$user = db_fetch_object($qid, 0);
-	if ($user->priv == "admin" || $SESSION["user"]["priv"] != "admin") {
+	if ($user->priv == "admin" || !($SESSION["user"]["priv"] == "admin")) {
 		return 1;
 	}
 
@@ -207,7 +230,7 @@ function get_category_tree($id=1) {
 	$qid = db_query("SELECT parent_id, name FROM categories WHERE id = '$id' ORDER BY on_special, name");
 	if (db_num_rows($qid)) {
 		list($parent, $name) = db_fetch_row($qid, 0);
-		$name = "<a href='$CFG->wwwroot/shopping/?id=$id'>" . stripslashes($name) . "</a>";
+		$name = "<a href='$CFG->wwwroot/shopping/?id=$id'>$name</a>";
 	} else {
 		$parent = 1;
 		$name = "";
@@ -266,8 +289,8 @@ function save_orderinfo(&$frm) {
 	$order->city = $frm["city"];
 	$order->state = $frm["state"];
 	$order->zip_code = $frm["zip_code"];
-//	$order->creditcard = $frm["creditcard"];
-//	$order->expiry = $frm["expiry"];
+	$order->creditcard = $frm["creditcard"];
+	$order->expiry = $frm["expiry"];
 	$order->comments = $frm["comments"];
 	
 	$SESSION["orderinfo"] = $order;
@@ -686,10 +709,8 @@ function validate_contact($contact, &$errors, &$msg) {
 	} else {
 		$contact = ereg_replace (" ", "", $contact);
 		$contact = ereg_replace ("\+", "", $contact);
-		$contact = ereg_replace ("\-", "", $contact);
 		$contact = ereg_replace ("\(", "", $contact);
 		$contact = ereg_replace ("\)", "", $contact);
-		$contact = ereg_replace ("\/", "", $contact);
 		eregi ("[0-9]+", $contact, $matched_contact);
 		if ($contact != $matched_contact[0]) {
 			$errors->contact = true;
@@ -712,10 +733,8 @@ function validate_fax($fax, &$errors, &$msg) {
 	} else {
 		$fax = ereg_replace (" ", "", $fax);
 		$fax = ereg_replace ("\+", "", $fax);
-		$fax = ereg_replace ("\-", "", $fax);
 		$fax = ereg_replace ("\(", "", $fax);
 		$fax = ereg_replace ("\)", "", $fax);
-		$fax = ereg_replace ("\/", "", $fax);
 		eregi ("[0-9]+", $fax, $matched_fax);
 		if ($fax != $matched_fax[0]) {
 			$errors->fax = true;
@@ -738,10 +757,8 @@ function validate_mobilephone($mobilephone, &$errors, &$msg) {
 	} else {
 		$mobilephone = ereg_replace (" ", "", $mobilephone);
 		$mobilephone = ereg_replace ("\+", "", $mobilephone);
-		$mobilephone = ereg_replace ("\-", "", $mobilephone);
 		$mobilephone = ereg_replace ("\(", "", $mobilephone);
 		$mobilephone = ereg_replace ("\)", "", $mobilephone);
-		$mobilephone = ereg_replace ("\/", "", $mobilephone);
 		eregi ("[0-9]+", $mobilephone, $matched_mobilephone);
 		if ($mobilephone != $matched_mobilephone[0]) {
 			$errors->mobilephone = true;
