@@ -36,8 +36,7 @@ $The_category = "La categoria";
 $Brand = "Marca";
 $Brands = "Marche";
 $The_brand = "La marca";
-global $IVA;	// taken from application.inc.php where the scope is a problem
-$The_IVA_Percentual = "La percentuale di " . $IVA;
+$The_IVA_Percentual = "La percentuale di IVA";
 $Product = "Prodotto";
 $Products = "Prodotti";
 $The_product = "Il prodotto";
@@ -47,7 +46,7 @@ $Edit_Product = "Modifica prodotto";
 $Items = "pezzi";
 $Add_Subcategory = "Aggiungi sottocategoria";
 $Add_Brand = "Aggiungi marca";
-$Add_IVA = "Aggiungi " . $IVA;
+$Add_IVA = "Aggiungi IVA";
 $back = "indietro";
 $BACK = "INDIETRO";
 $Address = "Via/Piazza";
@@ -106,7 +105,7 @@ $Insufficient_Privileges = "Diritti insufficienti";
 $PgMarket_Login = $CFG->myname . " Login";
 $PgMarket_Login_Page = $CFG->myname . ": pagina di login";
 $sign_up_for_an_account_now = "Se non sei gi&agrave; iscritto a questo negozio elettronico, iscriviti ora:";
-$dont_login_back_to_home_page = "Se non desideri ancora effettuare la procedura di login, <a href=\"".$CFG->wwwroot."\">clicca qui</a> per tornare alla pagina principale (home page).";
+$dont_login_back_to_home_page = "Se non desideri ancora effettuare la procedura di login, <a href=\"".$CFG->firstpage."\">clicca qui</a> per tornare alla pagina principale (home page).";
 $Special_Products = "Prodotti speciali";
 
 ////////////////////////////////////////////////////////////
@@ -118,8 +117,8 @@ $Categories_Management = "Amministrazione delle categorie";
 $C_Import_Categories = "Importa categorie";
 $Brands_Management = "Amministrazione delle marche";
 $C_Import_Brands = "Importa marche";
-$C_Import_IVA = "Importa percentuali " . $IVA;
-$IVA_Management = "Amministrazione dei valori di " . $IVA;
+$C_Import_IVA = "Importa percentuali IVA";
+$IVA_Management = "Amministrazione dei valori di IVA";
 $Orders_Log_ca = "Diario degli ordini - Contrassegno";
 $Orders_Log_cc = "Diario degli ordini - Carta di Credito";
 $Products_Management = "Amministrazione dei prodotti";
@@ -143,8 +142,8 @@ $Extended_Description = "Descrizione estesa";
 $Discount = "Sconto";
 $Starting_from = "a partire da";
 $C_Add_Category = "[+C] Aggiungi categoria";
-$C_Add_Brand = "[+M] Aggiungi marca";
-$C_Add_IVA = "[+I] Aggiungi percentuale " . $IVA;
+$C_Add_Brand = "[+C] Aggiungi marca";
+$C_Add_IVA = "[+C] Aggiungi percentuale IVA";
 $C_Add_Product = "[+P] Aggiungi prodotto";
 $Action = "Azione";
 $User = "Utente";
@@ -164,10 +163,10 @@ $Add_a_subcategory_under = "Aggiungi una sottocategoria di";
 $Add_a_product_under = "Aggiungi un prodotto a";
 $Edit_this_category = "Modifica questa categoria";
 $Edit_this_brand = "Modifica questa marca";
-$Edit_this_IVA = "Modifica questa percentuale di " . $IVA;
+$Edit_this_IVA = "Modifica questa percentuale di IVA";
 $admin_footer_message = $CFG->myname . " \"<i>Commercio elettronico - Electronic Store</i>\"";
 $Brand_reset_for_products = "La marca &egrave; stata azzerata per i prodotti di tale marca";
-$IVA_reset_for_products = "La percentuale di " . $IVA . " &egrave; stata azzerata per i prodotti con tale " . $IVA;
+$IVA_reset_for_products = "La percentuale di IVA &egrave; stata azzerata per i prodotti con tale IVA";
 $Users = "Utenti";
 $Edit_this_order = "Modifica questo ordine";
 $Delete_this_order = "Cancella questo ordine";
@@ -389,7 +388,7 @@ $customer_too_long = "Campo Cliente troppo lungo: " . $appoggio . " caratteri ma
 $empty_contact = "Non &egrave; stato specificato un recapito telefonico";
 $contact_too_long = "Recapito telefonico troppo lungo: ".$SESSION["phone_length"]." caratteri max";
 $contact_too_short = "Recapito telefonico troppo corto: ".$SESSION["phone_length_min"]." caratteri min";
-$not_valid_contact = "Recapito telefonico non valido; sono ammessi solo spazi, cifre e i seguenti caratteri: +-()/";
+$not_valid_contact = "Recapito telefonico non valido";
 $comments_too_long = "Commenti troppo lunghi: ".$SESSION["comments_length"]." caratteri max";
 
 ////////////////////////////////////////////////////////////
@@ -424,7 +423,7 @@ $brand_name_too_long = "Il nome della marca &egrave; troppo lungo: ".$SESSION["b
 $brand_description_too_long = "La descrizione della marca &egrave; troppo lunga: ".$SESSION["brand_description_length"]." caratteri max";
 
 $Err_ImpBrand = ": La Marca non esiste - '";
-$Err_ImpIVA = ": La " . $IVA . " non esiste - '";
+$Err_ImpIVA = ": L'IVA non esiste - '";
 
 ////////////////////////////////////////////////////////////
 // add and update product
@@ -445,8 +444,8 @@ $price_is_zero = "Il Prezzo deve essere maggiore di zero";
 $price_notint = "Il campo del Prezzo deve contenere un numero intero, quindi solo cifre, nessun altro carattere";
 $price_notfloat = "Il campo del Prezzo deve contenere un numero decimale, quindi solo cifre e al pi&ugrave; un punto decimale, nessun altro carattere";
 
-$not_valid_iva = "Valore della " . $IVA . " non valido";
-$iva_not_between_0_and_100 = "La " . $IVA . " non &egrave; compresa tra 0 e 100";
+$not_valid_iva = "Valore dell'IVA non valido";
+$iva_not_between_0_and_100 = "L'IVA non &egrave; compresa tra 0 e 100";
 
 $discount_not_completely_defined = "Se si vuole fare sconti sul prodotto, bisogna riempire sia il campo \"" . $Discount . "\" che il campo \"" . $Starting_from . "\"; se non si vuole fare sconti sul prodotto, lasciare vuoti entrambi i campi";
 $not_valid_discount = "Sconto non valido";
@@ -518,7 +517,7 @@ $F_Subset_or_Equal = "contenuto nella";
 
 $connection_error = "Errore di connessione alla base di dati";
 
-$submission_to_banca_sella = "Pagamento con Carta di Credito tramite Banca Sella";
+$submission_to_banca_sella = "Pagamento con Carta di Credito";
 $no_more_passwordric = "Sono temporaneamente finite le password necessarie per l'interfacciamento con E-Commerce Online, impossibile effettuare il pagamento con Carta di Credito";
 
 ?>
