@@ -36,8 +36,7 @@ $The_category = "The category";
 $Brand = "Brand";
 $Brands = "Brands";
 $The_brand = "The brand";
-global $IVA;	// taken from application.inc.php where the scope is a problem
-$The_IVA_Percentual = "The " . $IVA . " percentual";
+$The_IVA_Percentual = "The IVA percentual";
 $Product = "Product";
 $Products = "Products";
 $The_product = "The product";
@@ -47,7 +46,7 @@ $Edit_Product = "Edit Product";
 $Items = "items";
 $Add_Subcategory = "Add Subcategory";
 $Add_Brand = "Add Brand";
-$Add_IVA = "Add " . $IVA;
+$Add_IVA = "Add IVA";
 $back = "back";
 $BACK = "BACK";
 $Address = "Address";
@@ -106,7 +105,7 @@ $Insufficient_Privileges = "Insufficient Privileges";
 $PgMarket_Login = $CFG->myname . " Login";
 $PgMarket_Login_Page = $CFG->myname . ": Login Page";
 $sign_up_for_an_account_now = "If you do not already have an account, please sign up for an account now:";
-$dont_login_back_to_home_page = "If you do not wish to login yet, <a href=\"".$CFG->wwwroot."\">click here</a> to return to the home page.";
+$dont_login_back_to_home_page = "If you do not wish to login yet, <a href=\"".$CFG->firstpage."\">click here</a> to return to the home page.";
 $Special_Products = "Special Products";
 
 ////////////////////////////////////////////////////////////
@@ -118,8 +117,8 @@ $Categories_Management = "Category Management";
 $C_Import_Categories = "Import categories";
 $Brands_Management = "Brands Management";
 $C_Import_Brands = "Import Brands";
-$C_Import_IVA = "Import ". $IVA . " percentuals";
-$IVA_Management = $IVA . " Management";
+$C_Import_IVA = "Import IVA percentuals";
+$IVA_Management = "IVA Management";
 $Orders_Log_ca = "Orders Log - Cash On Delivery";
 $Orders_Log_cc = "Orders Log - Credit Card";
 $Products_Management = "Products Management";
@@ -143,8 +142,8 @@ $Extended_Description = "Extended Description";
 $Discount = "Discount";
 $Starting_from = "starting from";
 $C_Add_Category = "[+C] Add Category";
-$C_Add_Brand = "[+B] Add Brand";
-$C_Add_IVA = "[+I] Add " . $IVA . " percentual";
+$C_Add_Brand = "[+C] Add Brand";
+$C_Add_IVA = "[+C] Add IVA percentual";
 $C_Add_Product = "[+P] Add Product";
 $Action = "Action";
 $User = "User";
@@ -164,10 +163,10 @@ $Add_a_subcategory_under = "Add a subcategory under";
 $Add_a_product_under = "Add a product under";
 $Edit_this_category = "Edit this category";
 $Edit_this_brand = "Edit this brand";
-$Edit_this_IVA = "Edit this " . $IVA . " percentual";
+$Edit_this_IVA = "Edit this IVA percentual";
 $admin_footer_message = $CFG->myname . " \"<i>Electronic Store - Commercio elettronico</i>\"";
 $Brand_reset_for_products = "The Brand has been reset for all products of that brand";
-$IVA_reset_for_products = "The " . $IVA . " percentual has been reset for all products with that " . $IVA . " percentual";
+$IVA_reset_for_products = "The IVA percentual has been reset for all products with that IVA percentual";
 $Users = "Users";
 $Edit_this_order = "Edit this order";
 $Delete_this_order = "Delete this order";
@@ -386,7 +385,7 @@ $customer_too_long = "Customer too much long: " . $appoggio . " characters max";
 $empty_contact = "You did not specify a Phone to contact you";
 $contact_too_long = "Contact Phone number too much long: ".$SESSION["phone_length"]." characters max";
 $contact_too_short = "Contact Phone number too much short: ".$SESSION["phone_length_min"]." characters min";
-$not_valid_contact = "Contact Phone number not valid; only cyphers, spaces, +-()/ are allowed characters";
+$not_valid_contact = "Contact Phone number not valid";
 $comments_too_long = "Comments too much long: ".$SESSION["comments_length"]." characters max";
 
 ////////////////////////////////////////////////////////////
@@ -421,7 +420,7 @@ $brand_name_too_long = "Brand Name too much long: ".$SESSION["brand_name_length"
 $brand_description_too_long = "Brand Description too much long: ".$SESSION["brand_description_length"]." characters max";
 
 $Err_ImpBrand = ": the Brand doesn't exist - '";
-$Err_ImpIVA = ": the " . $IVA . " doesn't exist - '";
+$Err_ImpIVA = ": the IVA doesn't exist - '";
 
 ////////////////////////////////////////////////////////////
 // add and update product
@@ -442,8 +441,8 @@ $price_is_zero = "The Price must be greater than zero";
 $price_notint = "The Price entry must contain an integer number: only ciphers, not any other character";
 $price_notfloat = "The Price entry must contain a float number: only ciphers and optionally a dot, not any other character";
 
-$not_valid_iva = $IVA . " not valid";
-$iva_not_between_0_and_100 = "The " . $IVA . " is not between 0 and 100";
+$not_valid_iva = "IVA not valid";
+$iva_not_between_0_and_100 = "The IVA is not between 0 and 100";
 
 $discount_not_completely_defined = "If you want to discount the product, you have to fill both the fields \"" . $Discount . "\" and \"" . $Starting_from . "\"; if you do not want to discount the product, please leave empty both the fields";
 $not_valid_discount = "Discount not valid";
@@ -515,7 +514,7 @@ $F_Subset_or_Equal = "contained in";
 
 $connection_error = "Connection error to the database";
 
-$submission_to_banca_sella = "Credit Card payment through Banca Sella";
+$submission_to_banca_sella = "Credit Card payment";
 $no_more_passwordric = "At the present time, all the passwords available for interfacing with E-Commerce Online have been used, hence at this moment it is impossible to pay through the Credit Card";
 
 ?>
