@@ -23,5 +23,5 @@ include("application.inc.php");
 /* unset the SESSION["user"] variable to log out the user */
 unset($SESSION["user"]);
 
-header("Location: $CFG->wwwroot");
+header("Location: $CFG->firstpage");
 ?>
