@@ -27,6 +27,6 @@ $CART->recalc_total();
 if (! empty($HTTP_REFERER)) {
 	header("Location: $HTTP_REFERER");
 } else {
-	header("Location: $CFG->wwwroot");
+	header("Location: $CFG->firstpage");
 }
 ?>
